# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.application_config import ApplicationConfig  # noqa: E501
from agilicus_api.rest import ApiException

class TestApplicationConfig(unittest.TestCase):
    """ApplicationConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ApplicationConfig
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.application_config.ApplicationConfig()  # noqa: E501
        if include_optional :
            return ApplicationConfig(
                authentication_config = agilicus_api.models.application_authentication_config.ApplicationAuthenticationConfig(
                    application_handles_authentication = False, 
                    session_secret = 'Gns5ZPCvXGjzrtB672HAxfoSQ0dmqriSgiQf6uEQSBU=', ), 
                oidc_config = agilicus_api.models.oidc_proxy_config.OIDCProxyConfig(
                    headers = agilicus_api.models.oidc_proxy_header.OIDCProxyHeader(
                        domain_substitution = agilicus_api.models.oidc_proxy_domain_substitution.OIDCProxyDomainSubstitution(
                            standard_headers = agilicus_api.models.oidc_proxy_standard_header.OIDCProxyStandardHeader(
                                location = True, 
                                origin = True, 
                                host = True, ), 
                            other_headers = [
                                agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                    name = 'Accept-Encoding', 
                                    value = '*', )
                                ], ), 
                        header_overrides = agilicus_api.models.oidc_proxy_header_override.OIDCProxyHeaderOverride(
                            request = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(
                                set = [
                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                        name = 'Accept-Encoding', 
                                        value = '*', )
                                    ], 
                                add = [
                                    agilicus_api.models.oidc_proxy_header_mapping.OIDCProxyHeaderMapping(
                                        name = 'Accept-Encoding', 
                                        value = '*', )
                                    ], 
                                remove = [
                                    agilicus_api.models.oidc_proxy_header_name.OIDCProxyHeaderName(
                                        name = '0', )
                                    ], ), 
                            response = agilicus_api.models.oidc_proxy_header_user_config.OIDCProxyHeaderUserConfig(), ), ), 
                    domain_mapping = agilicus_api.models.oidc_proxy_domain_mapping.OIDCProxyDomainMapping(
                        primary_external_name = 'app-1.cloud.egov.city', 
                        primary_internal_name = 'app-1.internal', 
                        other_mappings = [
                            agilicus_api.models.oidc_proxy_domain_name_mapping.OIDCProxyDomainNameMapping(
                                internal_name = 'local_test_app', 
                                external_name = 'app-1', )
                            ], ), 
                    auth = agilicus_api.models.oidc_auth_config.OIDCAuthConfig(
                        auth_enabled = True, 
                        client_id = 'admin-portal', 
                        issuer = 'https://auth.cloud.egov.city', 
                        logout_url = '/login/logout.cfm', 
                        scopes = [
                            agilicus_api.models.oidc_proxy_scope.OIDCProxyScope(
                                name = 'urn:agilicus:app:app-1:owner', )
                            ], 
                        path_config = agilicus_api.models.oidc_auth_path_config.OIDCAuthPathConfig(
                            included_paths = [{"path":"/login"}], 
                            excluded_paths = [{"path":"/logout"}], ), ), 
                    content_manipulation = agilicus_api.models.oidc_proxy_content_manipulation.OIDCProxyContentManipulation(
                        media_types = [
                            agilicus_api.models.oidc_content_type.OIDCContentType(
                                name = 'text/css', )
                            ], ), 
                    upstream_config = agilicus_api.models.oidc_proxy_upstream_config.OIDCProxyUpstreamConfig(
                        scheme = 'https', 
                        hostname = 'httpbin.org', ), )
            )
        else :
            return ApplicationConfig(
        )

    def testApplicationConfig(self):
        """Test ApplicationConfig"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
