# coding: utf-8

"""
    Agilicus API

    Agilicus API.  A rendered, online viewable and usable version of this specification is available at [api](https://www.agilicus.com/api).  This API releases on Bearer-Token authentication. To obtain a valid bearer token you will need to Authenticate to an Issuer with OpenID Connect (a superset of OAUTH2).  Your \"issuer\" will look like https://auth.MYDOMAIN. For example, when you signed-up, if you said \"use my own domain name\" and assigned a CNAME of cloud.example.com, then your issuer would be https://auth.cloud.example.com. If you selected \"use an Agilicus supplied domain name\", your issuer would look like https://auth.myorg.agilicus.cloud.  For test purposes you can use our [Python SDK](https://pypi.org/project/agilicus/) and run `agilicus-cli --issuer https://auth.MYDOMAIN get-token`.  This API may be used in any language runtime that supports OpenAPI 3.0, or, you may use our [Python SDK](https://pypi.org/project/agilicus/), our [Typescript SDK](https://www.npmjs.com/package/@agilicus/angular), or our [Golang SDK](https://git.agilicus.com/pub/sdk-go).  100% of the activities in our system our API-driven, from our web-admin, through our progressive web applications, to all internals: there is nothing that is not accessible.  For more information, see [developer resources](https://www.agilicus.com/developer).   # noqa: E501

    The version of the OpenAPI document: 2021.04.30
    Contact: dev@agilicus.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import agilicus_api
from agilicus_api.models.mfa_enrollment_answer import MFAEnrollmentAnswer  # noqa: E501
from agilicus_api.rest import ApiException

class TestMFAEnrollmentAnswer(unittest.TestCase):
    """MFAEnrollmentAnswer unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test MFAEnrollmentAnswer
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = agilicus_api.models.mfa_enrollment_answer.MFAEnrollmentAnswer()  # noqa: E501
        if include_optional :
            return MFAEnrollmentAnswer(
                result = agilicus_api.models.mfa_enrollment_answer_result.MFAEnrollmentAnswerResult(
                    action = 'enroll', 
                    supported_mfa_methods = ["totp","webauthn"], )
            )
        else :
            return MFAEnrollmentAnswer(
                result = agilicus_api.models.mfa_enrollment_answer_result.MFAEnrollmentAnswerResult(
                    action = 'enroll', 
                    supported_mfa_methods = ["totp","webauthn"], ),
        )

    def testMFAEnrollmentAnswer(self):
        """Test MFAEnrollmentAnswer"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
